@@ -81,17 +81,48 @@ UBX_PAYLOADS_POLL = {
     # *************************************************
     "MGA-DBD": {},
     # *************************************************
+    "MON-COMMS": {},
     "MON-GNSS": {},
-    "MON-HW2": {},
     "MON-HW": {},
+    "MON-HW2": {},
+    "MON-HW3": {},
     "MON-IO": {},
     "MON-MGSPP": {},
     "MON-PATCH": {},
+    "MON-RF": {},
     "MON-RXBUF": {},
     "MON-SMGR": {},
+    "MON-SPAN": {},
     "MON-TXBUF": {},
     "MON-VER": {},
     # *************************************************
+    "NAV-CLOCK": {},
+    "NAV-DOP": {},
+    "NAV-GEOFENCE": {},
+    "NAV-HPPOSECEF": {},
+    "NAV-HPPOSLLH": {},
+    "NAV-ODO": {},
+    "NAV-ORB": {},
+    "NAV-POSECEF": {},
+    "NAV-POSLLH": {},
+    "NAV-PVT": {},
+    "NAV-RELPOSNED": {},
+    "NAV-SAT": {},
+    "NAV-SBAS": {},
+    "NAV-SIG": {},
+    "NAV-SLAS": {},
+    "NAV-STATUS": {},
+    "NAV-SVIN": {},
+    "NAV-TIMEBDS": {},
+    "NAV-TIMEGAL": {},
+    "NAV-TIMEGLO": {},
+    "NAV-TIMELS": {},
+    "NAV-QZSS": {},
+    "NAV-TIMEUTC": {},
+    "NAV-VELECEF": {},
+    "NAV-VELNED": {},
+    # *************************************************
+    "RXM-MEASX": {},
     "RXM-IMES": {},
     "RXM-RAW": {},
     "RXM-RAWX": {},
